Changelog
*********

0.1.0 (2017-10-12)
==================

- Add update_page and action_performed methods on navigation.
- Wait for pages to load when visiting them.


0.0.1 (2017-06-13)
==================

* First release

